# Methods

The following sections demonstrate basic usage of the three main categories of methods exposed by the client object.

* [Reading](read.md)
* [Creating/updating](create-update.md)
* [Deleting](delete.md)


For a complete list of methods, see the [Endpoints Overview](/endpoints/).
